@@ -31,7 +31,8 @@
 #' pc1 <- my_age(x = net$ldv, y = PC_G, name = "PC")
 #' pcw <- temp_fact(net$ldv+net$hdv, pc_profile)
 #' speed <- netspeed(pcw, net$ps, net$ffs, net$capacity, net$lkm, alpha = 1)
-#' pckm <- fkm[[1]](1:24); pckma <- cumsum(pckm)
+#' pckm <- units::set_units(fkm[[1]](1:24), "km")
+#' pckma <- cumsum(pckm)
 #' cod1 <- emis_det(po = "CO", cc = 1000, eu = "III", km = pckma[1:11])
 #' cod2 <- emis_det(po = "CO", cc = 1000, eu = "I", km = pckma[12:24])
 #' #vehicles newer than pre-euro
@@ -40,24 +41,15 @@
 #' lef <- ef_ldv_scaled(co1, cod, v = "PC", t = "4S", cc = "<=1400",
 #'                      f = "G",p = "CO", eu=co1$Euro_LDV)
 #' E_CO <- emis(veh = pc1,lkm = net$lkm, ef = lef, speed = speed, agemax = 41,
-#'              profile = pc_profile, hour = 24, day = 7, array = T)
+#'               profile = pc_profile, simplify = TRUE)
 #' class(E_CO)
-#' E_CO_STREETS <- emis_post(arra = E_CO, pollutant = "CO", by = "streets_wide")
-#' net@data <- cbind(net@data, E_CO_STREETS)
-#' head(net@data)
+#' E_CO_STREETS <- emis_post(arra = E_CO, pollutant = "CO", by = "streets", net = net)
 #' g <- make_grid(net, 1/102.47/2, 1/102.47/2) #500m in degrees
-#' net@data <- net@data[,- c(1:9)]
-#' names(net)
-#' E_CO_g <- emis_grid(spobj = net, g = g, sr= 31983)
-#' head(E_CO_g) #class sf
-#' library(mapview)
-#' mapview(E_CO_g, zcol= "V1", legend = T, col.regions = cptcity::cptcity(1))
+#' E_CO_g <- emis_grid(spobj = E_CO_STREETS, g = g, sr= 31983)
 #' gr <- GriddedEmissionsArray(E_CO_g, rows = 19, cols = 23, times = 168, T)
 #' plot(gr)
-#'
 #' # For some cptcity color gradients:
-#' devtools::install_github("ibarraespinosa/cptcity")
-#' plot(gr, col = cptcity::cptcity(1))
+#' plot(gr, col = cptcity::cpt(1))
 #' }
 #' @export
 GriddedEmissionsArray <- function(x, ..., cols, rows, times = ncol(x),
@@ -65,7 +57,7 @@ GriddedEmissionsArray <- function(x, ..., cols, rows, times = ncol(x),
   x$id <- NULL
   if(inherits(x, "Spatial")){
   df <- sf::st_as_sf(x)
-  df <- sf::st_set_geometry(x, NULL)
+  df <- sf::st_set_geometry(df, NULL)
   } else if(inherits(x, "sf")){
     df <- sf::st_set_geometry(x, NULL)
   } else {
@@ -88,10 +80,6 @@ GriddedEmissionsArray <- function(x, ..., cols, rows, times = ncol(x),
   }
 
   class(e) <- c("GriddedEmissionsArray",class(e))
-  cat("This GriddedEmissionsArray has:\n",
-      rows, "lat points\n",
-      cols, "lon points\n",
-      times,  "hours\n")
   return(e)
 }
 
@@ -100,13 +88,11 @@ GriddedEmissionsArray <- function(x, ..., cols, rows, times = ncol(x),
 #' @export
 print.GriddedEmissionsArray <- function(x,  ...) {
   e <- x
-if (is.array(e)) {
-    cat("This GriddedEmissionsArray has:\n",
-        dim(e)[1], "lat points\n",
-        dim(e)[2], "lon points\n",
-        dim(e)[3], "hours\n\n")
+  cat(paste0("This GriddedEmissionsArray has:\n",
+                 dim(e)[1], " lat points\n",
+                 dim(e)[2], " lon points\n",
+                 dim(e)[3],  " hours\n"))
   print(utils::head(e))
-  }
 }
 
 #' @rdname GriddedEmissionsArray
@@ -114,7 +100,7 @@ if (is.array(e)) {
 #' @export
 summary.GriddedEmissionsArray <- function(object, ...) {
   e <- object
-  summary(e[ , ,  ])
+  summary(e[, , ])
   }
 
 #' @rdname GriddedEmissionsArray
