@@ -51,6 +51,12 @@ age_ldv <- function (x,
                      namerows){
   # check na
   x[is.na(x)] <- 0
+
+  # length k
+  if(length(k)  > 1 & length(k) < length(x)){
+    stop("length of 'k' must be 1 ore equal to length of 'x'")
+  }
+
   #check agemax
   if(agemax < 1) stop("Agemax should be bigger than 1")
 
@@ -79,11 +85,7 @@ age_ldv <- function (x,
 
     names(df) <- paste(name,seq(1,agemax),sep="_")
 
-    if(length(k) > 1){
-      df <- vein::matvect(df = df, x = k)
-    } else {
       df <- df*k
-    }
 
 
     if(verbose){
@@ -124,11 +126,7 @@ age_ldv <- function (x,
 
     names(df) <- paste(name,seq(1,agemax),sep="_")
 
-    if(length(k) > 1){
-      df <- vein::matvect(df = df, x = k)
-    } else {
       df <- df*k
-    }
 
     if(verbose){
     message(paste("Average age of",name, "is",
