@@ -3,23 +3,24 @@
 #' @description \code{\link{emis_merge}} reads rds files and returns a data-frame
 #'  or an object of 'spatial feature' of streets, merging several files.
 #'
-#' @param path Character. Path where emissions are located
 #' @param pol Character. Pollutant.
 #' @param what Character. Word to search the emissions names, "STREETS", "DF" or
 #' whatever name. It is important to include the extension .'rds'. For instance,
 #' If you have several files "XX_CO_STREETS.rds", what should be "STREETS.rds"
-#' @param net 'Spatial feature' or 'SpatialLinesDataFrame' with the streets.
-#' It is expected #' that the number of rows is equal to the number of rows of
-#' street emissions. If #' not, the function will stop.
 #' @param streets Logical. If true, \code{\link{emis_merge}} will read the street
 #' emissions created with \code{\link{emis_post}} by "streets_wide", returning an
 #' object with class 'sf'. If false, it will read the emissions data-frame and
 #' rbind them.
+#' @param net 'Spatial feature' or 'SpatialLinesDataFrame' with the streets.
+#' It is expected #' that the number of rows is equal to the number of rows of
+#' street emissions. If #' not, the function will stop.
+#' @param ignore Character; Which pollutants or other charavter would you like to remove?
+#' @param FN Character indicating the function. Default is "sum"
+#' @param path Character. Path where emissions are located
 #' @param crs coordinate reference system in numeric format from
 #' http://spatialreference.org/ to transform/project spatial data using sf::st_transform
 #' @param under "Character"; "after" when you stored your pollutant x as 'X_'
 #' "before" when '_X' and "none" for merging directly the files.
-#' @param ignore "Logical"; Would you liek your selection?
 #' @param as_list "Logical"; for returning the results as list or not.
 #' @return 'Spatial feature' of lines or a dataframe of emissions
 #' @importFrom data.table rbindlist .SD
@@ -33,12 +34,13 @@ emis_merge <- function (pol = "CO",
                         what = "STREETS.rds",
                         streets = T,
                         net,
+                        FN = "sum",
+                        ignore,
                         path = "emi",
                         crs,
                         under = "after",
-                        ignore = FALSE,
                         as_list = FALSE){
-
+  # nocov start
   x <- list.files(path = path,
                   pattern = what,
                   all.files = T,
@@ -54,33 +56,31 @@ emis_merge <- function (pol = "CO",
   }
 
 
-
-nx <- gsub(pattern = paste0(getwd(), '/', path),
-           replacement = "", x = x)
-kk <- substr(x = nx, start = 11, stop = 50)
-kk <- gsub(pattern = "/", replacement = "", kk)
-kk <- gsub(pattern = ".rds", replacement = "", kk)
-nx <- kk
-
-  cat("\nReading emissions from:\n")
-  print(x)
-  if(ignore) {
-    ignore_this <- readline("Which ones would you to exclude?\n")
-    x <- x[!x %in% ignore_this]
+  if(!missing(ignore)) {
+    bo <- grepl(pattern = ignore, x = x)
+    x <- x[!bo]
+    cat("\nReading emissions from:\n")
+    print(x)
+  } else {
+    cat("\nReading emissions from:\n")
+    print(x)
   }
+
+  # reading
   x_rds <- lapply(x, readRDS)
-  names(x_rds) <- nx
+
   if(as_list) return(x_rds)
 
+  # colnames used for aggregating data.table
   nombres <- names(x_rds[[1]])
-  if(any(is.numeric(as.numeric(nombres)))) paste0("h", nombres)
+
   if(streets){
     for (i in 1:length(x_rds)){
       x_rds[[i]]$id <- 1:nrow(x_rds[[i]])
     }
 
     x_st <- data.table::rbindlist(x_rds)
-    x_st <- as.data.frame(x_st[, lapply(.SD, sum, na.rm=TRUE),
+    x_st <- as.data.frame(x_st[, lapply(.SD, eval(parse(text = FN)), na.rm=TRUE),
                                by = "id",
                                .SDcols = nombres ])
     if(nrow(x_st) != nrow(net)){
@@ -96,5 +96,6 @@ nx <- kk
     x_st <- as.data.frame(data.table::rbindlist(x_rds))
     return(x_st)
   }
+  # nocov end
 }
 
